@@ -92,7 +92,6 @@ gst_time_tool_class_init (GstTimeToolClass *class)
 static void
 get_ntp_service (GstTimeTool *tool)
 {
-	GstTimeToolPrivate *priv = GST_TIME_TOOL_GET_PRIVATE (tool);
 	GObject *service;
 	OobsList *list;
 	OobsListIter iter;
@@ -117,17 +116,26 @@ get_ntp_service (GstTimeTool *tool)
 static void
 gst_time_tool_init (GstTimeTool *tool)
 {
-	OobsList *list;
+	DBusError error;
 	GstTimeToolPrivate *priv = GST_TIME_TOOL_GET_PRIVATE (tool);
 
-	priv->bus_connection = dbus_bus_get (DBUS_BUS_SESSION, NULL);
+	dbus_error_init (&error);
+	priv->bus_connection = dbus_bus_get (DBUS_BUS_SESSION, &error);
 	priv->cookie = 0;
 
-	tool->time_config = oobs_time_config_get (GST_TOOL (tool)->session);
-	tool->ntp_config = oobs_ntp_config_get (GST_TOOL (tool)->session);
-	tool->services_config = oobs_services_config_get (GST_TOOL (tool)->session);
+	if (dbus_error_is_set (&error)) {
+		g_warning ("%s", error.message);
+		dbus_error_free (&error);
+	}
 
-	get_ntp_service (tool);
+	tool->time_config = oobs_time_config_get ();
+	gst_tool_add_configuration_object (GST_TOOL (tool), tool->time_config, TRUE);
+
+	tool->ntp_config = oobs_ntp_config_get ();
+	gst_tool_add_configuration_object (GST_TOOL (tool), tool->ntp_config, TRUE);
+
+	tool->services_config = oobs_services_config_get ();
+	gst_tool_add_configuration_object (GST_TOOL (tool), tool->services_config, TRUE);
 }
 
 static void
@@ -138,6 +146,9 @@ inhibit_screensaver (GstTimeTool *tool,
 	DBusMessage *message, *reply;
 	DBusMessageIter iter;
 
+	if (!priv->bus_connection)
+		return;
+
 	if (inhibit) {
 		const gchar *appname = "Time-admin";
 		const gchar *reason = "Changing time";
@@ -182,7 +193,6 @@ inhibit_screensaver (GstTimeTool *tool,
 static gboolean
 on_apply_timeout (GstTimeTool *tool)
 {
-	GstTimeToolPrivate *priv = GST_TIME_TOOL_GET_PRIVATE (tool);
 	guint year, month, day, hour, minute, second;
 
 	gtk_calendar_get_date (GTK_CALENDAR (tool->calendar), &year, &month, &day);
@@ -196,7 +206,7 @@ on_apply_timeout (GstTimeTool *tool)
 				   (gint) year, (gint) month, (gint) day,
 				   (gint) hour, (gint) minute, (gint)second);
 
-	oobs_object_commit (tool->time_config);
+	gst_tool_commit (GST_TOOL (tool), tool->time_config);
 	gst_time_tool_start_clock (tool);
 
 	inhibit_screensaver (tool, FALSE);
@@ -335,9 +345,9 @@ init_timezone (GstTimeTool *time_tool)
 {
 	GstTool *tool = GST_TOOL (time_tool);
 	GtkWidget *w;
+	GtkCellRenderer *cell;
 	GPtrArray *locs;
-	GList *combo_locs = NULL;
-	int i;
+	guint i;
 
 	time_tool->tzmap = e_tz_map_new (tool);
 	g_return_if_fail (time_tool->tzmap != NULL);
@@ -347,6 +357,9 @@ init_timezone (GstTimeTool *time_tool)
 	gtk_widget_show (GTK_WIDGET (time_tool->tzmap->map));
 
 	w = gst_dialog_get_widget (tool->main_dialog, "location_combo");
+	cell = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (w), cell, TRUE);
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (w), cell, "text", 0, NULL);
 	locs = tz_get_locations (e_tz_map_get_tz_db (time_tool->tzmap));
 
 	for (i = 0; i < locs->len; i++)
@@ -364,6 +377,14 @@ check_ntp_support (GstTool  *tool)
 
 	if (GST_TIME_TOOL (tool)->ntp_service)
 		return TRUE;
+	else {
+		/* Be sure we take into account newly installed NTP support */
+		oobs_object_update (OOBS_OBJECT (GST_TIME_TOOL (tool)->services_config));
+		get_ntp_service (GST_TIME_TOOL (tool));
+
+		if (GST_TIME_TOOL (tool)->ntp_service)
+			return TRUE;
+	}
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "configuration_options");
 	g_signal_handler_block (widget, priv->configuration_changed_id);
@@ -402,10 +423,9 @@ on_option_configuration_changed (GtkWidget *widget,
 		oobs_service_set_runlevel_configuration (time_tool->ntp_service,
 							 (OobsServicesRunlevel *) runlevel,
 							 (active) ? OOBS_SERVICE_START : OOBS_SERVICE_STOP,
-							 /* FIXME: hardcoded priority? */
-							 50);
+							 0);
 
-		gst_tool_commit_async (GST_TOOL (time_tool), time_tool->services_config,
+		gst_tool_commit_async (GST_TOOL (time_tool), OOBS_OBJECT (time_tool->ntp_service),
 				       (active) ? _("Enabling NTP") : _("Disabling NTP"),
 				       NULL, NULL);
 	}
@@ -421,30 +441,6 @@ on_synchronize_now_clicked (GtkWidget *widget, gpointer data)
 			       _("Synchronizing system clock"), NULL, NULL);
 }
 
-static void
-add_synchronize_now_button (GstTimeTool *tool)
-{
-	GtkDialog *dialog = GTK_DIALOG (GST_TOOL (tool)->main_dialog);
-	GtkWidget *box, *image, *label;
-
-	image = gtk_image_new_from_stock ("gnome-stock-timer", GTK_ICON_SIZE_BUTTON);
-	label = gtk_label_new_with_mnemonic ("_Synchronize now");
-
-	box   = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (box), image, FALSE, FALSE, 0);
-	gtk_box_pack_end (GTK_BOX (box), label, TRUE, TRUE, 0);
-
-	tool->synchronize_now = gtk_button_new ();
-	gtk_container_add (GTK_CONTAINER (tool->synchronize_now), box);
-	gtk_widget_show_all (tool->synchronize_now);
-
-	gtk_box_pack_end (GTK_BOX (dialog->action_area), tool->synchronize_now, FALSE, FALSE, 0);
-	gtk_box_reorder_child (GTK_BOX (dialog->action_area), tool->synchronize_now, 0);
-
-	g_signal_connect (G_OBJECT (tool->synchronize_now), "clicked",
-			  G_CALLBACK (on_synchronize_now_clicked), tool);
-}
-
 static void
 on_option_changed (GtkWidget   *combo,
 		   GstTimeTool *time_tool)
@@ -466,13 +462,11 @@ on_option_changed (GtkWidget   *combo,
 	container = gst_dialog_get_widget (GST_TOOL (time_tool)->main_dialog, "configuration_container");
 
 	/* remove the child */
-	if (GTK_BIN (container)->child)
-		gtk_container_remove (GTK_CONTAINER (container), GTK_BIN (container)->child);
+	if (gtk_bin_get_child (GTK_BIN (container)))
+		gtk_container_remove (GTK_CONTAINER (container), gtk_bin_get_child (GTK_BIN (container)));
 
 	gtk_container_add (GTK_CONTAINER (container), widget);
 	gtk_widget_show_all (container);
-
-	gtk_widget_set_sensitive (time_tool->synchronize_now, (option == CONFIGURATION_MANUAL));
 }
 
 static void
@@ -488,7 +482,7 @@ add_option (GstTool      *tool,
 	toplevel = gtk_widget_get_toplevel (w);
 
 	g_object_ref (w);
-	gtk_container_remove (GTK_CONTAINER (w->parent), w);
+	gtk_container_remove (GTK_CONTAINER (gtk_widget_get_parent (w)), w);
 	gtk_widget_destroy (toplevel);
 
 	gtk_list_store_append (store, &iter);
@@ -561,9 +555,12 @@ gst_time_tool_constructor (GType                  type,
 
 	time_tool->ntp_list = ntp_servers_list_get (time_tool);
 	init_timezone (time_tool);
-	add_synchronize_now_button (time_tool);
 	add_options_combo (time_tool);
 
+	time_tool->synchronize_now = gst_dialog_get_widget (GST_TOOL (time_tool)->main_dialog, "update_time");
+	g_signal_connect (G_OBJECT (time_tool->synchronize_now), "clicked",
+			  G_CALLBACK (on_synchronize_now_clicked), time_tool);
+
 	gtk_window_set_resizable (GTK_WINDOW (GST_TOOL (time_tool)->main_dialog), FALSE);
 
 	return object;
@@ -573,7 +570,6 @@ static void
 gst_time_tool_finalize (GObject *object)
 {
 	GstTimeTool *tool = GST_TIME_TOOL (object);
-	GstTimeToolPrivate *priv = GST_TIME_TOOL_GET_PRIVATE (object);
 
 	/* FIXME: missing things to free */
 	g_object_unref (tool->time_config);
@@ -584,7 +580,6 @@ gst_time_tool_finalize (GObject *object)
 static void
 update_servers_list (GstTimeTool *tool)
 {
-	GstTimeToolPrivate *priv;
 	OobsList *list;
 	OobsListIter iter;
 	GObject *server;
@@ -641,14 +636,7 @@ gst_time_tool_update_gui (GstTool *tool)
 static void
 gst_time_tool_update_config (GstTool *tool)
 {
-	GstTimeTool *time_tool;
-
-	time_tool = GST_TIME_TOOL (tool);
-	oobs_object_update (time_tool->time_config);
-	oobs_object_update (time_tool->ntp_config);
-	oobs_object_update (time_tool->services_config);
-
-	get_ntp_service (time_tool);
+	get_ntp_service (GST_TIME_TOOL (tool));
 }
 
 static void
@@ -664,6 +652,8 @@ gst_time_tool_close (GstTool *tool)
 		on_apply_timeout (GST_TIME_TOOL (tool));
 	}
 
+	gst_time_tool_stop_clock (GST_TIME_TOOL (tool));
+
 	(* GST_TOOL_CLASS (gst_time_tool_parent_class)->close) (tool);
 }
 
@@ -673,7 +663,7 @@ gst_time_tool_new (void)
 	return g_object_new (GST_TYPE_TIME_TOOL,
 			     "name", "time",
 			     "title", _("Time and Date Settings"),
-			     "icon", "config-date",
+			     "icon", "time-admin",
 			     NULL);
 }
 
@@ -758,9 +748,7 @@ gst_time_tool_run_timezone_dialog (GstTimeTool *time_tool)
 	GtkWidget *label;
 	const gchar *timezone;
 	gchar *tz_name = NULL;
-	gchar *old_tz_name = NULL;
 	TzLocation *tz_location;
-	gint correction;
 
 	tool  = GST_TOOL (time_tool);
 	label = gst_dialog_get_widget (tool->main_dialog, "tzlabel");
@@ -771,16 +759,20 @@ gst_time_tool_run_timezone_dialog (GstTimeTool *time_tool)
 	gtk_window_set_transient_for (GTK_WINDOW (time_tool->timezone_dialog),
 				      GTK_WINDOW (tool->main_dialog));
 
+	gst_dialog_add_edit_dialog (tool->main_dialog, time_tool->timezone_dialog);
+
 	gtk_widget_show_all (time_tool->timezone_dialog);
 	gtk_dialog_run (GTK_DIALOG (time_tool->timezone_dialog));
-
 	gtk_widget_hide_all (time_tool->timezone_dialog);
+
+	gst_dialog_remove_edit_dialog (tool->main_dialog, time_tool->timezone_dialog);
+
 	tz_name     = e_tz_map_get_selected_tz_name (time_tool->tzmap);
 	tz_location = e_tz_map_get_location_by_name (time_tool->tzmap, tz_name);
 
 	if (!timezone || strcmp (tz_name, timezone) != 0) {
 		oobs_time_config_set_timezone (OOBS_TIME_CONFIG (time_tool->time_config), tz_name);
-		oobs_object_commit (time_tool->time_config);
+		gst_tool_commit (GST_TOOL (time_tool), time_tool->time_config);
 		gtk_label_set_text (GTK_LABEL (label), tz_name);
 	}
 }
