@@ -26,7 +26,6 @@
 #include <config.h>
 #include "gst.h"
 
-#include "passwd.h"
 #include "callbacks.h"
 #include "table.h"
 #include "user-settings.h"
@@ -40,35 +39,6 @@ extern GstTool *tool;
 
 /* Common stuff to users and groups tables */
 
-static void
-actions_set_sensitive (gint table, gint count)
-{
-	switch (table) {
-	case TABLE_USERS:
-		gst_dialog_try_set_sensitive (tool->main_dialog,
-					      gst_dialog_get_widget (tool->main_dialog, "user_new"),
-					      TRUE);
-		gst_dialog_try_set_sensitive (tool->main_dialog,
-					      gst_dialog_get_widget (tool->main_dialog, "user_delete"),
-					      (count > 0));
-		break;
-	case TABLE_GROUPS:
-		gst_dialog_try_set_sensitive (tool->main_dialog,
-					      gst_dialog_get_widget (tool->main_dialog, "group_new"),
-					      TRUE);
-		gst_dialog_try_set_sensitive (tool->main_dialog,
-					      gst_dialog_get_widget (tool->main_dialog, "group_delete"),
-					      (count > 0));
-		gst_dialog_try_set_sensitive (tool->main_dialog,
-					      gst_dialog_get_widget (tool->main_dialog, "group_settings"),
-					      (count == 1));
-		break;
-	default:
-		g_assert_not_reached ();
-		return;
-	}
-}
-
 void
 on_table_selection_changed (GtkTreeSelection *selection, gpointer data)
 {
@@ -86,8 +56,6 @@ on_table_selection_changed (GtkTreeSelection *selection, gpointer data)
 	if (!user)
 		return;
 
-	actions_set_sensitive (table, count);
-
 	/* Show the settings for the selected user */
 	user_settings_show (user);
 
@@ -159,8 +127,7 @@ on_table_button_press (GtkTreeView *treeview, GdkEventButton *event, gpointer da
 	}
 
 	if (cont != 0 && (event->type == GDK_2BUTTON_PRESS || event->type == GDK_3BUTTON_PRESS)
-	    && (table == TABLE_GROUPS)
-	    && gst_dialog_is_authenticated (tool->main_dialog))
+	    && (table == TABLE_GROUPS))
 		on_group_settings_clicked (NULL, NULL);
 
 	return FALSE;
@@ -210,6 +177,12 @@ on_manage_groups_clicked (GtkWidget *widget, gpointer user_data)
 	GtkWidget *dialog;
 
 	dialog = gst_dialog_get_widget (tool->main_dialog, "groups_dialog");
+
+	/* Force reloading configuration. This is needed when an user was just
+	 * created/deleted, in which case groups may have changed. */
+	oobs_object_update (GST_USERS_TOOL (tool)->groups_config);
+	gst_users_tool_update_gui (tool);
+
 	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (tool->main_dialog));
 	while (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_HELP);
 	gtk_widget_hide (dialog);
@@ -227,6 +200,10 @@ on_group_new_clicked (GtkButton *button, gpointer user_data)
 	OobsResult result;
 	gint response;
 
+	/* Before going further, check for authorizations, authenticating if needed */
+	if (!gst_tool_authenticate (tool, GST_USERS_TOOL (tool)->groups_config))
+		return;
+
 	group = oobs_group_new (NULL);
 	parent_dialog = gst_dialog_get_widget (tool->main_dialog, "groups_dialog");
 	dialog = group_settings_dialog_new (group);
@@ -237,6 +214,11 @@ on_group_new_clicked (GtkButton *button, gpointer user_data)
 	if (response == GTK_RESPONSE_OK) {
 		group = group_settings_dialog_get_group ();
 		config = OOBS_GROUPS_CONFIG (GST_USERS_TOOL (tool)->groups_config);
+
+		/* We need to know about this group before adding it, else we won't be aware
+		 * that we triggered the commit, and we will show a "Reload config?" dialog. */
+		gst_tool_add_configuration_object (tool, OOBS_OBJECT (group), FALSE);
+
 		result = oobs_groups_config_add_group (config, group);
 
 		if (result == OOBS_RESULT_OK)
@@ -269,16 +251,22 @@ on_group_settings_clicked (GtkButton *button, gpointer user_data)
 	gtk_tree_model_get (model, &iter,
 			    COL_GROUP_OBJECT, &group,
 			    -1);
+	
 	dialog = group_settings_dialog_new (group);
 	parent_dialog = gst_dialog_get_widget (tool->main_dialog, "groups_dialog");
 
 	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent_dialog));
 	response = group_settings_dialog_run (dialog, group);
 
-	if (response == GTK_RESPONSE_OK) {
+	/* This is the only dialog we show without authentication, because it's the only
+	 * way to get some informations. Committing without authorization could leave
+	 * changes in queue in case of failure, which would get committed with
+	 * the first successful commit later! */
+	if (response == GTK_RESPONSE_OK
+	    && gst_tool_authenticate (tool, OOBS_OBJECT (group))) {
 		group_settings_dialog_get_data (group);
 		groups_table_set_group (group, &iter);
-		gst_tool_commit (tool, GST_USERS_TOOL (tool)->groups_config);
+		gst_tool_commit (tool, OOBS_OBJECT (group));
 	}
 
 	g_object_unref (group);
@@ -291,7 +279,12 @@ on_group_delete_clicked (GtkButton *button, gpointer user_data)
 	GtkTreePath *path;
 	GList *list, *elem;
 
-	list = elem = table_get_row_references (TABLE_GROUPS, &model);
+	list = elem = groups_table_get_row_references ();
+	model = groups_table_get_model ();
+
+	/* Before going further, check for authorizations, authenticating if needed */
+	if (!gst_tool_authenticate (tool, GST_USERS_TOOL (tool)->groups_config))
+		return;
 
 	while (elem) {
 		path = gtk_tree_row_reference_get_path (elem->data);
@@ -305,54 +298,6 @@ on_group_delete_clicked (GtkButton *button, gpointer user_data)
 	g_list_free (list);
 }
 
-/* User settings callbacks */
-
-void
-on_user_settings_passwd_changed (GtkEntry *entry, gpointer data)
-{
-	g_object_set_data (G_OBJECT (entry), "changed", GINT_TO_POINTER (TRUE));
-}
-
-void
-on_user_settings_passwd_random_new (GtkButton *button, gpointer data)
-{
-	GtkWidget *widget;
-	gchar *passwd;
-
-	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_random_passwd");
-
-	passwd = passwd_get_random ();
-	gtk_entry_set_text (GTK_ENTRY (widget), passwd);
-	g_free (passwd);
-}
-
-void
-on_user_settings_passwd_toggled (GtkToggleButton *toggle, gpointer data)
-{
-	GtkWidget *user_passwd_random_new = gst_dialog_get_widget (tool->main_dialog, "user_passwd_random_new");
-	GtkWidget *user_passwd_random_entry = gst_dialog_get_widget (tool->main_dialog, "user_settings_random_passwd");
-	GtkWidget *user_passwd_entry1 = gst_dialog_get_widget (tool->main_dialog, "user_settings_passwd1");
-	GtkWidget *user_passwd_entry2 = gst_dialog_get_widget (tool->main_dialog, "user_settings_passwd2");
-	GtkToggleButton *pwd_manual = GTK_TOGGLE_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_manual"));
-	
-
-	if (gtk_toggle_button_get_active (pwd_manual)) {
-		gtk_widget_set_sensitive (user_passwd_random_new, FALSE);
-		gtk_widget_set_sensitive (user_passwd_random_entry, FALSE);
-		gtk_widget_set_sensitive (user_passwd_entry1, TRUE);
-		gtk_widget_set_sensitive (user_passwd_entry2, TRUE);
-		gtk_entry_set_text (GTK_ENTRY (user_passwd_random_entry), "");
-	} else {
-		gtk_widget_set_sensitive (user_passwd_random_new, TRUE);
-		gtk_widget_set_sensitive (user_passwd_random_entry, TRUE);
-		gtk_widget_set_sensitive (user_passwd_entry1, FALSE);
-		gtk_widget_set_sensitive (user_passwd_entry2, FALSE);
-		gtk_entry_set_text (GTK_ENTRY (user_passwd_entry1), "");
-		gtk_entry_set_text (GTK_ENTRY (user_passwd_entry2), "");
-		on_user_settings_passwd_random_new (NULL, NULL);
-	}
-}
-
 void
 on_groups_dialog_show_help (GtkWidget *widget, gpointer data)
 {
