@@ -27,6 +27,7 @@
 #include <string.h>
 
 #include "gst.h"
+#include "user-password.h"
 #include "users-tool.h"
 #include "users-table.h"
 #include "user-settings.h"
@@ -50,9 +51,6 @@ void on_user_settings_passwd_toggled      (GtkToggleButton *toggle,
 void on_passwd_entry_changed              (GtkWidget *entry,
                                            gpointer   user_data);
 
-void on_edit_user_passwd                  (GtkButton *button,
-                                           gpointer   user_data);
-
 gboolean on_user_passwd_current_focus_out (GtkWidget *entry,
                                            GdkEventFocus *event,
                                            gpointer user_data);
@@ -97,7 +95,7 @@ check_password (OobsUser *user)
 	}
 	else if (len < 6) {
 		primary_text = _("Password is too short");
-		secondary_text = _("User passwords must be longer than 6 characters and preferably "
+		secondary_text = _("User passwords must be longer than 5 characters and preferably "
 		                   "formed by numbers, letters and special characters.");
 	} else if (strcmp (password, confirmation) != 0) {
 		primary_text = _("Password confirmation is not correct");
@@ -202,7 +200,7 @@ prepare_edit_dialog (GtkDialog *dialog,
 
 	/* Set user name */
 	user = users_table_get_current ();
-	name = oobs_user_get_full_name (user);
+	name = oobs_user_get_full_name_fallback (user);
 	gtk_label_set_text (name_label, name);
 	g_object_unref (user);
 
@@ -368,6 +366,15 @@ finish_password_change ()
 		}
 	}
 
+	/* We know we've set a non-empty password */
+	oobs_user_set_password_empty (user, FALSE);
+
+	/* Unlock account, this may not be what is wanted, but that's the only solution
+	 * since 'passwd' doesn't differentiate accounts with no passwords yet from disabled ones */
+	oobs_user_set_password_disabled (user, FALSE);
+
+	user_settings_show (user);
+
 	gst_dialog_remove_edit_dialog (tool->main_dialog, GTK_WIDGET (user_passwd_dialog));
 	gtk_widget_hide (GTK_WIDGET (user_passwd_dialog));
 
